"use strict";

/*************************************************************************************************/
/* Custom variables - divs are automatically made into vars in vars.min.js ***********************/
/*************************************************************************************************/

var tl = gsap.timeline(),
	buttonArray, button, disabledArray, disabledButton, clickthroughArray, clickthroughButton, type,
	i, j;



/*************************************************************************************************/
/* Banner initialisation, loading, event listening etc *******************************************/
/*************************************************************************************************/

function init() {

	addEventListeners();

	politeInit();
	
	// (Enabler.isPageLoaded()) ? politeInit() : Enabler.addEventListener(studio.events.StudioEvent.PAGE_LOADED, politeInit);


}

function addEventListeners() {
	buttonArray = [container];
	for (i = 0; i < buttonArray.length; i++) {
		button = buttonArray[i];
		button.style.cursor = "pointer";
		button.addEventListener("mouseover", buttonHandler, false);
		button.addEventListener("mouseout", buttonHandler, false);
		button.addEventListener("click", buttonHandler, false);
	}

	disabledArray = [];
	for (i = 0; i < disabledArray.length; i++) {
		disabledButton = disabledArray[i];
		disabledButton.style.pointerEvents = "none";
	}
}

function politeInit() {
	console.log(":: starting polite load ::");


	setTimeout(function() {
		politeLoad([
			{url:"images/bg.jpg", div:"background"},
			// {url:"images/portal_glow_1.png", div:"portalGlow1"},
			// {url:"images/portal_glow_2.png", div:"portalGlow2"},
			{url:"images/end_glow.jpg", div:"portalGlow3"},
			{url:"images/top_glow.jpg", div:"topGlow"},
			{url:"images/end_glow.jpg", div:"endGlow"},
			{url:"images/headline1.png", div:"headline1"},
			{url:"images/headline2.png", div:"headline2"},
			{url:"images/ctacopy.png", div:"ctaCopy"},
			{url:"images/ctaseq.png", div:"ctaSeq"},
			{url:"images/logo.png", div:"logo"},
			{url:"images/product_logos.png", div:"BTsport"},
			{url:"images/product_logos.png", div:"champLeague"},
			{url:"images/left.png", div:"left"},
			{url:"images/right.png", div:"right"},
			{url:"images/front.png", div:"front"},
			{url:"images/front.png", div:"hand"},
			{url:"images/bg2.png", div:"bg2"},
			{url:"images/headline_end.png", div:"get"},
			{url:"images/headline_end.png", div:"superfast"},
			{url:"images/price.png", div:"price"},
			{url:"images/hub.png", div:"hub"},

		],

		function() {
			console.log(":: all loads complete ::");
			gsap.delayedCall(0.2, function() { tl.play(); });
		});
	}, 2000);
}


/*************************************************************************************************/
/* Timeline & any other animation & logic ********************************************************/
/*************************************************************************************************/


		tl


		.set([portalGlow1, portalGlow2], {autoAlpha:0.8})
		// .set(portalGlow3, {autoAlpha:0.5})




		.addLabel("start")
		.to(preloader, {duration:0.35, autoAlpha:0, ease:"quad.inOut", overwrite:false}, "start")
		.from(topGlow, {duration:2, autoAlpha:0, ease:"quad.inOut", repeat:-1, yoyo:true}, "animateFrame1")

		.addLabel("animateFrame1", 0.5)


		.from(left, {duration:0.9, autoAlpha:0, x:-240, ease:"expo.out"}, "animateFrame1")
		.to(left, {duration:1.8, x:0, ease:"quad.out", overwrite:false}, "animateFrame1+=0.4")
		.from(right, {duration:0.9, autoAlpha:0, x:240, ease:"expo.out"}, "animateFrame1")
		.to(right, {duration:1.8, x:0, ease:"quad.out", overwrite:false}, "animateFrame1+=0.4")
		.from([front, hand], {duration:0.9, autoAlpha:0, y:240, ease:"expo.out"}, "animateFrame1")
		.to([front, hand], {duration:1.8, y:0, ease:"quad.out", overwrite:false}, "animateFrame1+=0.4")
		.from([headline1, headline2], {duration:0.9, autoAlpha:0, y:20, ease:"expo.out"}, "animateFrame1+=0.2")

		// .addPause("animateFrame1+=1.4")

		.addLabel("animateFrame2", 1.4)

		.to([headline1, headline2], {duration:0.6, autoAlpha:0, ease:"expo.in"}, "animateFrame2")
		.to(left, {duration:0.6, autoAlpha:0, x:-300, ease:"expo.in"}, "animateFrame2+=0.2")
		.to(right, {duration:0.6, autoAlpha:0, x:300, ease:"expo.in"}, "animateFrame2+=0.2")
		.to([front, hand], {duration:0.6, autoAlpha:0, y:349, ease:"expo.in"}, "animateFrame2+=0.2")

		.from(bg2, {duration:1.5, autoAlpha:0}, "animateFrame2+=0.2")

		.to(BTsport, {duration:0.9, autoAlpha:0, y:20, ease: "back.in(1.7)"}, "animateFrame2+=0.2")
		.to(champLeague, {duration:0.9, autoAlpha:0, y:20, ease: "back.in(1.7)"}, "animateFrame2+=0.3")

		.addLabel("animateFrame3", 3.3)
		.from(get, {duration:0.9, autoAlpha:0, y:10, ease: "back.out(1.2)"}, "animateFrame3")
		.from(superfast, {duration:0.9, autoAlpha:0, y:10, ease: "back.out(1.2)"}, "animateFrame3+=0.2")

		.from(price, {duration:0.9, autoAlpha:0, y:10, ease: "back.out(1.2)"}, "animateFrame3+=0.4")
		.from(hub, {duration:0.9, autoAlpha:0, y:250, ease: "expo.out"}, "animateFrame3+=0.5")
		
		.from([ctaCopy, ctaSeq], {duration:0.8, autoAlpha:0, y:100, ease: "back.out(1.7)"}, "animateFrame3+=0.5")
		// .call(saatchi.spritesheet.play, [ctaSeq, 970, 7250, 1, "vertical", false, 0], "animateFrame3+=1.3")


	
		
		.addLabel("end", 8)
		.from(endGlow, {duration:2, autoAlpha:0, ease:"quad.inOut"}, "end")
		.set(topGlow, {autoAlpha:0}, "end+=0.2")



		.call(function() {
			gsap.killTweensOf(topGlow);
		}, [], "end")

		.pause();
		







/*************************************************************************************************/
/* Event handlers ********************************************************************************/
/*************************************************************************************************/


function buttonHandler($e) {
	button 	= $e.currentTarget;
	type	= $e.type;

	switch (button) {
		case container:
			if 		(type === "mouseover") 	{  }
			else if (type === "mouseout") 	{  }
			// else if (type === "click") 		{ Enabler.exitOverride("banner_clickthrough", dynamicContent.BT_JAN_SALE_2021_Sheet1[0].Exit_URL.Url); introVideo.pause(), introVideo.currentTime = 15, tl.play("end")} //comment out if standard
			// else if (type === "click") 		{ Enabler.exit("BG Exit", addSuffix(),"exit_suffix");} //uncomment if standard
			else if (type === "click") 		{ 	window.open(clickTag); console.log('clickthrough to ' + clickTag);}
			break;
	}
}





/*************************************************************************************************/
/* Check page and Enabler has been loaded and initialised ****************************************/
/*************************************************************************************************/

// function checkEnabler() {
// 	(Enabler.isInitialized()) ? enablerInitHandler() : Enabler.addEventListener(studio.events.StudioEvent.INIT, enablerInitHandler);
// }

// function enablerInitHandler() {
// 	(Enabler.isVisible()) ? init() : Enabler.addEventListener(studio.events.StudioEvent.VISIBLE, init);
// }

init();

domready(function() {
	console.log(":: dom ready ::");
//	if (elementScrape()) checkEnabler();
});



/*************************************************************************************************/
/* Adding Suffix to dynamic URL ****************************************/
/*************************************************************************************************/


function addSuffix(url, dcmParameter) { 
	
	  var urlSuffix = Enabler.getParameter(dcmParameter); 
	  var _url = ''; 
	
	  if (url) { 
		var symbol = (url.indexOf('?') > -1) ? '&': '?'; 
		if(urlSuffix) { 
		  while (urlSuffix.charAt(0) == '?' || urlSuffix.charAt(0) == '&') { 
			urlSuffix = urlSuffix.substring(1); 
		  } 
		  if (urlSuffix.indexOf('?') > -1) { 
			urlSuffix = urlSuffix.replace(/\?/g, '&'); 
		  } 
		} 
		_url = url + symbol + urlSuffix; 
	  } 
	  return _url; 
	} 