"use strict";

/*************************************************************************************************/
/* Custom variables - divs are automatically made into vars in vars.min.js ***********************/
/*************************************************************************************************/

var tl = gsap.timeline(),
	buttonArray, button, disabledArray, disabledButton, clickthroughArray, clickthroughButton, type,
	i, j;

/*************************************************************************************************/
/* Banner initialisation, loading, event listening etc *******************************************/
/*************************************************************************************************/

function init() {
	createTimeline();
	addEventListeners();
	
	(Enabler.isPageLoaded()) ? politeInit() : Enabler.addEventListener(studio.events.StudioEvent.PAGE_LOADED, politeInit);
}

function addEventListeners() {
	buttonArray = [container];
	for (i = 0; i < buttonArray.length; i++) {
		button = buttonArray[i];
		button.style.cursor = "pointer";
		button.addEventListener("mouseover", buttonHandler, false);
		button.addEventListener("mouseout", buttonHandler, false);
		button.addEventListener("click", buttonHandler, false);
	}

	disabledArray = [];
	for (i = 0; i < disabledArray.length; i++) {
		disabledButton = disabledArray[i];
		disabledButton.style.pointerEvents = "none";
	}
}

function politeInit() {
	console.log(":: starting polite load ::");

	setTimeout(function() {
		politeLoad([
			{url:"images/background1.jpg", div:"background1"},
			{url:"images/background2.png", div:"background2"},
			{url:"images/background3.png", div:"background3"},
			{url:"images/bumblebee.png", div:"bumblebee"},
			{url:"images/bumblebeeEyes.png", div:"bumblebeeEyes"},
			{url:"images/lensFlare.png", div:"lensFlare"},
			// {url:"images/copy.png", div:"copy"},
			{url:"images/lockup.png", div:"lockup"},
			{url:"images/legals.png", div:"legals"},
			{url:"images/copy1.png", div:"copy1"},
			{url:"images/copy2.png", div:"copy2"},
			{url:"images/copy3.png", div:"copy3"},
		],

		function() {
			console.log(":: all loads complete ::");
			gsap.delayedCall(0.5, function() { tl.play(); });
		});
	}, 3000);
}





/*************************************************************************************************/
/* Timeline & any other animation & logic ********************************************************/
/*************************************************************************************************/

function createTimeline() {


    tl  .call(function() {

		})
		
		if (/Edge/.test(navigator.userAgent)) {

		tl.set(copy1, {x:0, y:0, autoAlpha:1})
		.set(copy2, {x:0, y:0, autoAlpha:1})
		.set(copy3, {x:0, y:0, autoAlpha:1})
        .set(background1, {x:-410})
        .set(background2, {x:-370})
		.set(background3, {x:-320})
		// .set(lockup, {y:0, autoAlpha:0})
        //.set(lensFlare, {transformOrigin:"63% 35%", x:-385, y:-350, scale:0.35, autoAlpha:0, rotation:40})
        .set([bumblebee, bumblebeeEyes], {x:-50})
        .set(bumblebeeEyes, {autoAlpha:0})
        .addLabel("start")
        .to(preloader, {duration:0.35, autoAlpha:0, ease:"quad.inOut", overwrite:false}, "start")
		.addLabel("frame1", 0)
		
        .pause();


		}else{

			tl.set(copy1, {x:-25, y:0, autoAlpha:1})
		.set(copy2, {x:25, y:0, autoAlpha:1})
		.set(copy3, {x:-25, y:0, autoAlpha:1})
        .set(background1, {x:-170})
        .set(background2, {x:-120})
		.set(background3, {x:-100})
		// .set(lockup, {y:0, autoAlpha:0})
        .set(lensFlare, {transformOrigin:"63% 35%", x:-385, y:-350, scale:0.35, autoAlpha:0, rotation:40})
        .set([bumblebee, bumblebeeEyes], {x:120})
        .set(bumblebeeEyes, {autoAlpha:0})
        .addLabel("start")
        .to(preloader, {duration:0.35, autoAlpha:0, ease:"quad.inOut", overwrite:false}, "start")
        .addLabel("frame1", 0)
		.to(lensFlare, {duration:3, transformOrigin:"63% 35%", x:-445, y:-350, scale:1, rotation:0, ease:"strong.out"}, "frame1")
		.to(lensFlare, {duration:6, transformOrigin:"63% 35%", x:-565, y:-350, scale:1, rotation:140, ease:"quad.out", overwrite:false}, "frame1+=2")

		.to(background1, {duration:3, x:-360, ease:"strong.out"}, "frame1")
		.to(background1, {duration:6, x:-410, ease:"quad.out", overwrite:false}, "frame1+=1.4")
		
		.to(background2, {duration:3, x:-295, ease:"strong.out"}, "frame1")
		.to(background2, {duration:6, x:-370, ease:"quad.out", overwrite:false}, "frame1+=1.4")

		.to(background3, {duration:3, x:-250, ease:"strong.out"}, "frame1")
		.to(background3, {duration:6, x:-320, ease:"quad.out", overwrite:false}, "frame1+=1.4")

		.to([bumblebee, bumblebeeEyes], {duration:3, x:-14, ease:"strong.out"}, "frame1")
		.to([bumblebee, bumblebeeEyes], {duration:6, x:-59, ease:"quad.out", overwrite:false}, "frame1+=1.4")

	
		 
		//.addLabel("frame2", 0.25)
		.to(copy1, {duration:0.3, x:-35, autoAlpha:1, ease:"strong.in", overwrite:false}, "frame1-=1")
		.to(copy1, {duration:6.5, x:0, ease:"quad.out", overwrite:false}, "frame1+=0.3")

		.to(copy2, {duration:0.3, x:-35, autoAlpha:1, ease:"strong.in", overwrite:false}, "frame1+=0.2")
		.to(copy2, {duration:6.5, x:0, ease:"quad.out", overwrite:false}, "frame1+=0.5")


		.to(copy3, {duration:0.3, x:35, autoAlpha:1, ease:"strong.in", overwrite:false}, "frame1+=0.3")
		.to(copy3, {duration:6.5, x:0, ease:"quad.out", overwrite:false}, "frame1+=0.6")


		.to(lockup, {duration:0.75, autoAlpha:1, ease:"quad.inOut", overwrite:false}, "frame1+=1")
		.to(lensFlare, {duration:3, ease:"rough({template:'power1.inOut', strength:3, points:30, taper:'both', randomize:true, clamp:false})", autoAlpha:1, overwrite:false}, "frame1")

		.addLabel("frame2", 4)
		.to(bumblebeeEyes, {duration:0.75, autoAlpha:1, ease:"quad.inOut", overwrite:false}, "frame2")
		.to(bumblebeeEyes, {duration:1.5, ease:"rough({template:'power1.inOut', strength:3, points:100, taper:'both', randomize:true, clamp:false})", autoAlpha:0, overwrite:false}, "frame2+=1")
        .pause();

		}


	
}




/*************************************************************************************************/
/* Event handlers ********************************************************************************/
/*************************************************************************************************/

function buttonHandler($e) {
	button 	= $e.currentTarget;
	type	= $e.type;

	switch (button) {
		case container:
			if 		(type === "mouseover") 	{  }
			else if (type === "mouseout") 	{  }
			else if (type === "click") 		{ Enabler.exit("Background Exit"); }
			break;
	}
}





/*************************************************************************************************/
/* Check page and Enabler has been loaded and initialised ****************************************/
/*************************************************************************************************/

function checkEnabler() {
	(Enabler.isInitialized()) ? enablerInitHandler() : Enabler.addEventListener(studio.events.StudioEvent.INIT, enablerInitHandler);
}

function enablerInitHandler() {
	(Enabler.isVisible()) ? init() : Enabler.addEventListener(studio.events.StudioEvent.VISIBLE, init);
}

domready(function() {
	console.log(":: dom ready ::");
	if (elementScrape()) checkEnabler();
});