"use strict";

/*************************************************************************************************/
/* Custom variables - divs are automatically made into vars in vars.min.js ***********************/
/*************************************************************************************************/

var tl = gsap.timeline(),
	buttonArray, button, disabledArray, disabledButton, clickthroughArray, clickthroughButton, type,
	i, j;

/*************************************************************************************************/
/* Banner initialisation, loading, event listening etc *******************************************/
/*************************************************************************************************/

function init() {
	createTimeline();
	addEventListeners();
	
	(Enabler.isPageLoaded()) ? politeInit() : Enabler.addEventListener(studio.events.StudioEvent.PAGE_LOADED, politeInit);
}

function addEventListeners() {
	buttonArray = [container];
	for (i = 0; i < buttonArray.length; i++) {
		button = buttonArray[i];
		button.style.cursor = "pointer";
		button.addEventListener("mouseover", buttonHandler, false);
		button.addEventListener("mouseout", buttonHandler, false);
		button.addEventListener("click", buttonHandler, false);
	}

	disabledArray = [];
	for (i = 0; i < disabledArray.length; i++) {
		disabledButton = disabledArray[i];
		disabledButton.style.pointerEvents = "none";
	}
}

function politeInit() {
	console.log(":: starting polite load ::");

	setTimeout(function() {
		politeLoad([
			{url:"images/background1.jpg", div:"background1"},
			{url:"images/background2.png", div:"background2"},
			{url:"images/background3.png", div:"background3"},
			{url:"images/copyBackground.png", div:"copyBackground"},
			{url:"images/bumblebee.png", div:"bumblebee"},
			{url:"images/bumblebeeEyes.png", div:"bumblebeeEyes"},
			{url:"images/lensFlare.png", div:"lensFlare"},
			{url:"images/copy1.png", div:"copy1"},
			{url:"images/copy2.png", div:"copy2"},
			{url:"images/lockup.png", div:"lockup"},
			{url:"images/legals.png", div:"legals"},
		],

		function() {
			console.log(":: all loads complete ::");
			gsap.delayedCall(0.5, function() { tl.play(); });
		});
	}, 3000);
}





/*************************************************************************************************/
/* Timeline & any other animation & logic ********************************************************/
/*************************************************************************************************/

function createTimeline() {
	tl	.call(function() {
			
		})

	if (/Edge/.test(navigator.userAgent)) {

		  tl.set(copy1, {x:0, y:0, autoAlpha:1})
			.set(copy2, {x:0, y:0, autoAlpha:1})
			.set(background1, {x:-300})
			.set(background2, {x:-300})
			.set(background3, {x:-300})
			// .set(lockup, {y:0, autoAlpha:0})
			//.set(lensFlare, {transformOrigin:"63% 35%", x:-385, y:-350, scale:0.35, autoAlpha:0, rotation:40})
			.set([bumblebee, bumblebeeEyes], {x:60})
			.set(bumblebeeEyes, {autoAlpha:0})
			.addLabel("start")
			.to(preloader, {duration:0.35, autoAlpha:0, ease:"quad.inOut", overwrite:false}, "start")
			.addLabel("frame1", 0)
			
			.pause();
	
	
	}else{

		tl.set(copyBackground, {alpha:0.6})
		  .set(background1, {x:-225})
		  .set(background2, {x:-150})
		  .set(background3, {x:0})
		  .set(lensFlare, {transformOrigin:"63% 35%", x:60, y:-350, scale:0.35, autoAlpha:0, rotation:-140})
		  .set([bumblebee, bumblebeeEyes], {x:300})
		  .set(bumblebeeEyes, {autoAlpha:0})
		  .set([copy1, copy2], {x:-35, autoAlpha:1})
	

		
		 .addLabel("start")
		  .to(preloader, {duration:0.35, autoAlpha:0, ease:"quad.inOut", overwrite:false}, "start")


		 .addLabel("frame1", 0)
		  .to(lensFlare, {duration:3, transformOrigin:"63% 35%", x:5, y:-350, scale:1, rotation:-20, ease:"strong.out"}, "frame1")
		  .to(lensFlare, {duration:6, transformOrigin:"63% 35%", x:-15, y:-350, scale:1, rotation:10, ease:"quad.out", overwrite:false}, "frame1+=2")

		  .to(background1, {duration:3, x:-280, ease:"strong.out"}, "frame1")
		  .to(background1, {duration:6, x:-300, ease:"quad.out", overwrite:false}, "frame1+=1.5")
		
		  .to(background2, {duration:3, x:-260, ease:"strong.out"}, "frame1")
		  .to(background2, {duration:6, x:-300, ease:"quad.out", overwrite:false}, "frame1+=1.5")

		  .to(background3, {duration:3, x:-240, ease:"strong.out"}, "frame1")
		  .to(background3, {duration:6, x:-300, ease:"quad.out", overwrite:false}, "frame1+=1.5")

		  .to([bumblebee, bumblebeeEyes], {duration:3, x:60, ease:"strong.out"}, "frame1")
		  .to([bumblebee, bumblebeeEyes], {duration:6, x:0, ease:"quad.out", overwrite:false}, "frame1+=1.5")
		  
		  .to(copy1, {duration:0.3, x:55, autoAlpha:1, ease:"strong.in", overwrite:false}, "frame1-=1")
		  .to(copy1, {duration:6.5, x:0, ease:"quad.out", overwrite:false}, "frame1+=0.3")
		  .to(copy2, {duration:0.3, x:-55, autoAlpha:1, ease:"strong.in", overwrite:false}, "frame1+=0.2")
		  .to(copy2, {duration:6.5, x:0, ease:"quad.out", overwrite:false}, "frame1+=0.5")

		  .to(lockup, {duration:0.75, autoAlpha:1, ease:"quad.inOut", overwrite:false}, "frame1+=1")
		  .to(lensFlare, {duration:3, ease:"rough({template:'power1.inOut', strength:3, points:30, taper:'both', randomize:true, clamp:false})", autoAlpha:1, overwrite:false}, "frame1")


		  .addLabel("frame2", 4)
		  .to(bumblebeeEyes, {duration:0.75, autoAlpha:1, ease:"quad.inOut", overwrite:false}, "frame2")
		  .to(bumblebeeEyes, {duration:1.5, ease:"rough({template:'power1.inOut', strength:3, points:80, taper:'both', randomize:true, clamp:false})", autoAlpha:0, overwrite:false}, "frame2+=1")


		  .pause();

	}
}





/*************************************************************************************************/
/* Event handlers ********************************************************************************/
/*************************************************************************************************/

function buttonHandler($e) {
	button 	= $e.currentTarget;
	type	= $e.type;

	switch (button) {
		case container:
			if 		(type === "mouseover") 	{  }
			else if (type === "mouseout") 	{  }
			else if (type === "click") 		{ Enabler.exit("Background Exit"); }
			break;
	}
}





/*************************************************************************************************/
/* Check page and Enabler has been loaded and initialised ****************************************/
/*************************************************************************************************/

function checkEnabler() {
	(Enabler.isInitialized()) ? enablerInitHandler() : Enabler.addEventListener(studio.events.StudioEvent.INIT, enablerInitHandler);
}

function enablerInitHandler() {
	(Enabler.isVisible()) ? init() : Enabler.addEventListener(studio.events.StudioEvent.VISIBLE, init);
}

domready(function() {
	console.log(":: dom ready ::");
	if (elementScrape()) checkEnabler();
});