"use strict";

/*************************************************************************************************/
/* Custom variables - divs are automatically made into vars in vars.min.js ***********************/
/*************************************************************************************************/

var tl = gsap.timeline(),
	buttonArray, button, disabledArray, disabledButton, clickthroughArray, clickthroughButton, type,
	i, j;



/*************************************************************************************************/
/* Banner initialisation, loading, event listening etc *******************************************/
/*************************************************************************************************/

function init() {
	addEventListeners();
	politeInit();
}

function addEventListeners() {
	buttonArray = [container];
	for (i = 0; i < buttonArray.length; i++) {
		button = buttonArray[i];
		button.style.cursor = "pointer";
		button.addEventListener("mouseover", buttonHandler, false);
		button.addEventListener("mouseout", buttonHandler, false);
		button.addEventListener("click", buttonHandler, false);
	}

	disabledArray = [];
	for (i = 0; i < disabledArray.length; i++) {
		disabledButton = disabledArray[i];
		disabledButton.style.pointerEvents = "none";
	}
}

function politeInit() {
	console.log(":: starting polite load ::");


	setTimeout(function() {
		politeLoad([
			{url:"images/image1.jpg", div:"image1"},
			{url:"images/image2.jpg", div:"image2"},
			{url:"images/image3.jpg", div:"image3"},
			{url:"images/copy1.png", div:"copy1"},
			{url:"images/copy2.png", div:"copy2"},
			{url:"images/copy3.png", div:"copy3"},
			{url:"images/copy4.png", div:"copy4"},
			{url:"images/logo_sml.png", div:"logoSml"},
			{url:"images/logo.png", div:"logo"},
			{url:"images/cta.png", div:"cta"},
		],

		function() {
			console.log(":: all loads complete ::");
			gsap.delayedCall(0.2, function() { tl.play(); });
		});
	}, 100);
}


/*************************************************************************************************/
/* Timeline & any other animation & logic ********************************************************/
/*************************************************************************************************/


tl	
		.set([image1, image2], {x:-330})
		// .set(copy1, {y:252})
		.set([copy1, copy2], {autoAlpha:0})


		.addLabel("start")
		.to(preloader, {duration:0.35, autoAlpha:0, ease:"quad.inOut", overwrite:false}, "start")
		.to(image1, {duration:13, x:-100, ease:"circ.out", overwrite: false}, "start")





		.addLabel("frame1", 0.5)
		.to(copy1, {duration:0.5, css:{filter:"blur(0px)"}, ease:"linear", overwrite:false}, "frame1")
		.to(copy1, {duration:0.5, autoAlpha:1, overwrite:false}, "frame1")


		.addLabel("frame2", 3)
		.to(copy1, {duration:0.5, autoAlpha:0, ease:"linear", overwrite:false}, "frame2")
		.to(image1, {duration:0.5, autoAlpha:0, ease:"linear", overwrite: false}, "frame2")
		.to(image2, {duration:13, x:-100, ease:"circ.out", overwrite: false}, "frame2-=1")
		.to(copy2, {duration:0.5, css:{filter:"blur(0px)"}, ease:"linear", overwrite:false}, "frame2+=1")
		.to(copy2, {duration:0.5, autoAlpha:1, overwrite:false}, "frame2+=1")



		.addLabel("frame3", 6)
		.to(copy2, {duration:0.5, autoAlpha:0, ease:"linear", overwrite:false}, "frame3")
		.to(image2, {duration:0.5, autoAlpha:0, ease:"linear", overwrite: false}, "frame3")
		.to(image3, {duration:13, x:-100, ease:"circ.out", overwrite: false}, "frame3-=1")
		.to(copy3, {duration:0.5, css:{filter:"blur(0px)"}, ease:"linear", overwrite:false}, "frame3+=1")
		.to(copy3, {duration:0.5, autoAlpha:1, overwrite:false}, "frame3+=1")
	
	
		.addLabel("frame4", 10)
		.from(endFrameContainer, {duration:0.5, autoAlpha:0, ease:"linear", overwrite:false}, "frame4")
		.from(logo, {duration:0.5, autoAlpha:0, ease:"linear", overwrite:false}, "frame4+=0.5")
		.from([copy4, cta], {duration:0.5, autoAlpha:0, ease:"linear", overwrite:false}, "frame4+=1")
	
    
    

		.addLabel("frame5", 11)


		.addLabel("end", 20)

		.call(function() {
		}, [], "end")


		.pause();
		







/*************************************************************************************************/
/* Event handlers ********************************************************************************/
/*************************************************************************************************/

function buttonHandler($e) {
	button 	= $e.currentTarget;
	type	= $e.type;

	switch (button) {
		case container:
			if 		(type === "mouseover") 	{ gsap.to(cta, {duration:0.2, alpha:0.75, ease:"quad.inOut"}); }
			else if (type === "mouseout") 	{ gsap.to(cta, {duration:0.2, alpha:1, ease:"quad.inOut"}); }
			else if (type === "click") 		{ window.open(clickTag); console.log('clickthrough to ' + clickTag); }
			break;
	}
}





/*************************************************************************************************/
/* Check page and Enabler has been loaded and initialised ****************************************/
/*************************************************************************************************/

domready(function() {
	console.log(":: dom ready ::");
	if (elementScrape()) init();
});