"use strict";

/*************************************************************************************************/
/* Custom variables - divs are automatically made into vars in vars.min.js ***********************/
/*************************************************************************************************/

var tl = gsap.timeline(),
	buttonArray, button, disabledArray, disabledButton, clickthroughArray, clickthroughButton, type,
	i, j;

/*************************************************************************************************/
/* Banner initialisation, loading, event listening etc *******************************************/
/*************************************************************************************************/

function init() {
	createTimeline();
	addEventListeners();

	politeLoad([
		{url:"images/camera.png", div:"camera"},
		{url:"images/crack.png", div:"crack"},
		{url:"images/phone.png", div:"phone"},
		{url:"images/card.png", div:"card"},
		{url:"images/poundnote.png", div:"poundNote"},
		{url:"images/poundnote.png", div:"poundNoteMiddle"},
		{url:"images/poundnote.png", div:"poundNoteBack"},
		{url:"images/icon.png", div:"icon"},
		{url:"images/logo.png", div:"logo"},
	],

	function() {
		console.log(":: all loads complete ::");
		gsap.delayedCall(0.5, function() { tl.play(); });
	});
}

function addEventListeners() {
	buttonArray = [container];
	for (i = 0; i < buttonArray.length; i++) {
		button = buttonArray[i];
		button.style.cursor = "pointer";
		button.addEventListener("mouseover", buttonHandler, false);
		button.addEventListener("mouseout", buttonHandler, false);
		button.addEventListener("click", buttonHandler, false);
	}

	disabledArray = [];
	for (i = 0; i < disabledArray.length; i++) {
		disabledButton = disabledArray[i];
		disabledButton.style.pointerEvents = "none";
	}
}





/*************************************************************************************************/
/* Timeline & any other animation & logic ********************************************************/
/*************************************************************************************************/

function createTimeline() {



		
	if (/Edge/.test(navigator.userAgent)) {

	}else{

	  tl

		.set([camera, crack], {transformOrigin:'50% 50%', rotation:-10})
		.set(text3, {transformOrigin:"20% 40%"})
		.set(text3b, {transformOrigin:"20% 20%"})
		.set(text4, {transformOrigin:"30% 50%"})
		.set(text4b, {transformOrigin:"50% 20%"})
		.set(icon, {transformOrigin:"67% 35%"})
		.set(text5, {transformOrigin:"50% 20%"})
		.set(text5b, {transformOrigin:"50% 20%"})
		.set(card, {x:-7})

		.set(poundNoteMiddle, {x:-4, y:-250})
		.set(poundNoteBack, {x:-6, y:-250})


		.set([logo, text6, cta], {y:20, autoAlpha:0})
			  
	 	.addLabel("start")
        .to(preloader, {duration:0.35, autoAlpha:0, ease:"quad.inOut", overwrite:false}, "start")

		
		.addLabel("animateFrame1", 0.5)

		//BARS ANIM//
		.from(topBar, {duration:0.3, x:-300, ease:"expo.easeInOut"}, "animateFrame1")
		.from(bottomBar, {duration:0.3, x:300,  ease:"expo.easeInOut"}, "animateFrame1")

		//CAMERA ANIMATION//
		.from([camera, crack], {duration:0.5, y:-250, ease:"bounce.out"}, "animateFrame1")
		.from(crack, {duration:0.5, autoAlpha:0}, "animateFrame1+=0.2")
		.set([camera, crack], {rotation:10}, "animateFrame1+=0.2")
		.to([camera, crack], {duration:0.1, rotation:0}, "animateFrame1+=0.5")


		//TEXT 1 IN//
		.from(text1, {duration:0.5, scale:0, ease:"expo.easeInOut"}, "animateFrame1+=0.6")
		//TEXT 2 IN//
		.from(text2, {duration:0.5, scale:0, ease:"expo.easeInOut"}, "animateFrame1+=1.1")

		// .addPause()

		//TEXT 1 and 2 OUT//
		.to([text1, text2], {duration:0.5, autoAlpha:0, ease:"expo.easeInOut"}, "animateFrame1+=3")


		.addLabel("animateFrame2", 4)
		//TEXT 3 IN//
		.from(text3, {duration:0.5, scale:0, ease:"expo.easeInOut"}, "animateFrame2")
		//PHONE IN//
		.fromTo(phone, {x:300}, {duration:1, x:-10, ease:"expo.easeInOut"}, "animateFrame2+=0.2")
		//CAMERA SCALE//
		.to([camera, crack], {duration:0.5, scale:0.35, x:85, y:-16, ease:"expo.easeInOut"}, "animateFrame2+=0.5")
		//TEXT 3b IN//
		.from(text3b, {duration:0.5, scale:0, ease:"expo.easeInOut"}, "animateFrame2+=1")
		//CARD IN//
		.from(card, {duration:0.5, y:250, ease:"expo.easeInOut"}, "animateFrame2+=1")

		// .addPause()

		//CARD PHONE CAMERA OUT//
		.to([card, phone, camera, crack], {duration:0.5, x:300, ease:"expo.easeInOut"}, "animateFrame2+=3")
		//TEXT 3 3b OUT//
		.to([text3, text3b], {duration:0.5, autoAlpha:0}, "animateFrame2+=3")

		.addLabel("animateFrame3", 7.5)

		//TEXT 4 IN//
		.from(text4, {duration:0.5, scale:0, ease:"expo.easeInOut"}, "animateFrame3")
		//NOTE IN//
		.from(poundNote, {duration:0.5, ease: "back.out(1.2)", y:250}, "animateFrame3")
		//ICON IN//
		.from(icon, {duration:0.5, scale:0, ease: "back.out(1.2)"},"animateFrame3+=0.1")
		//TEXT 4b IN//
		.from(text4b, {duration:0.5, scale:0, ease:"expo.easeInOut"}, "animateFrame3+=0.5")

		//ICON OUT//
		.to(icon, {duration:0.5, autoAlpha:0, scale:0, ease:"expo.easeInOut"}, "animateFrame3+=3")
		//TEXT 4 4b OUT//
		.to([text4, text4b], {duration:0.5, autoAlpha:0, ease:"expo.easeInOut"}, "animateFrame3+=3")


		// .addPause()

		.addLabel("animateFrame4", 11)

		//TEXT 5 IN//
		.from(text5, {duration:0.5, scale:0, ease:"expo.easeInOut"}, "animateFrame4")
		//NOTE ANIMATIONS//
		.to(poundNoteMiddle, {duration:0.5, y:4, ease:"expo.easeInOut"}, "animateFrame4+=0.5")
		.set(poundNote, {x:8, y:-10}, "animateFrame4+=1")
		.to(poundNoteBack, {duration:0.5, y:4, ease:"expo.easeInOut"}, "animateFrame4+=1")
		.set(poundNote, {x:18, y:-20}, "animateFrame4+=1.5")
		.set(poundNoteMiddle, {x:6, y:-8}, "animateFrame4+=1.5")

		//TEXT 5B IN//
		.from(text5b, {duration:0.5, scale:0, ease:"expo.easeInOut"}, "animateFrame4+=1.7")
		.from(legal, {duration:0.5, autoAlpha:0}, "animateFrame4+=1.7")


		.addLabel("animateFrame5", 15)

		//END FRAME WIPE//
		.from(blueWipe, {duration:0.5, y:-250, ease:'expo.easeInOut'}, "animateFrame5")
		.from(yellowWipe, {duration:0.5, y:250, ease:"expo.easeInOut"}, "animateFrame5")
		//LEGAL ANIM//
		.set(legal, {color:"#ffffff", zIndex:"2"}, "animateFrame5+=0.2")
		//END FRAME ELEMENT ANIM//
		.to([text6, logo, cta], {duration:1, y:0, autoAlpha:1, ease:"expo.easeInOut"}, "animateFrame5")

	

        .pause();

		}
	
}

/*************************************************************************************************/
/* Event handlers ********************************************************************************/
/*************************************************************************************************/

function buttonHandler($e) {
	button 	= $e.currentTarget;
	type	= $e.type;

	switch (button) {
		case container:
			if 		(type === "mouseover") 	{  }
			else if (type === "mouseout") 	{  }
			else if (type === "click") 		{ 	window.open(clickTag); console.log('clickthrough to ' + clickTag); }
			break;
	}
}





/*************************************************************************************************/
/* Check page and Enabler has been loaded and initialised ****************************************/
/*************************************************************************************************/

function checkEnabler() {
	(Enabler.isInitialized()) ? enablerInitHandler() : Enabler.addEventListener(studio.events.StudioEvent.INIT, enablerInitHandler);
}

function enablerInitHandler() {
	(Enabler.isVisible()) ? init() : Enabler.addEventListener(studio.events.StudioEvent.VISIBLE, init);
}

domready(function() {
	console.log(":: dom ready ::");
	if (elementScrape()) checkEnabler();
});