"use strict";

/*************************************************************************************************/
/* Custom variables - divs are automatically made into vars in vars.min.js ***********************/
/*************************************************************************************************/

var tl = gsap.timeline(),
	buttonArray, button, disabledArray, disabledButton, clickthroughArray, clickthroughButton, type,
	i, j;

/*************************************************************************************************/
/* Banner initialisation, loading, event listening etc *******************************************/
/*************************************************************************************************/

function init() {
	createTimeline();
	addEventListeners();

	(Enabler.isPageLoaded()) ? politeInit() : Enabler.addEventListener(studio.events.StudioEvent.PAGE_LOADED, politeInit);

}

function addEventListeners() {
	buttonArray = [container];
	for (i = 0; i < buttonArray.length; i++) {
		button = buttonArray[i];
		button.style.cursor = "pointer";
		button.addEventListener("mouseover", buttonHandler, false);
		button.addEventListener("mouseout", buttonHandler, false);
		button.addEventListener("click", buttonHandler, false);

	}

	disabledArray = [];
	for (i = 0; i < disabledArray.length; i++) {
		disabledButton = disabledArray[i];
		disabledButton.style.pointerEvents = "none";
	}
}


function politeInit() {
	console.log(":: starting polite load ::");

	setTimeout(function() {
		politeLoad([
			{url:"images/logo.png", div:"logo"},
			{url:"images/text1.png", div:"text1"},
			{url:"images/text2.png", div:"text2"},
			{url:"images/text3.png", div:"text3"},
			{url:"images/text4.png", div:"text4"},
			{url:"images/text5.png", div:"text5"},
			{url:"images/text6.png", div:"text6"},
			{url:"images/text7.png", div:"text7"},
			{url:"images/logosml.png", div:"logoSml"},
			{url:"images/300x600_POOL_IMAGE1.png", div:"img1"},
			{url:"images/300x600_POOL_IMAGE2.png", div:"img2"},
		],

		function() {
			console.log(":: all loads complete ::");
			gsap.delayedCall(0.5, function() { tl.play(); });
		});
	}, 3000);
}




/*************************************************************************************************/
/* Timeline & any other animation & logic ********************************************************/
/*************************************************************************************************/

function createTimeline() {



		
	if (/Edge/.test(navigator.userAgent)) {

	}else{

	  tl
	
		.set(logo, {y:100})
		.set([text3, text5, text6, text7] , {autoAlpha:0})

		.set([text1, text2, text3], {transformOrigin:"50% 75%"})
		.set([text4, text5, text6], {transformOrigin:"50% 80%"})

			  
	 	.addLabel("start")
        .to(preloader, {duration:0.35, autoAlpha:0, ease:"quad.inOut", overwrite:false}, "start")

		
		.addLabel("animateFrame1", 0.5)

		//BARS ANIM//
		.from(topBar, {duration:0.3, x:-300, ease:"expo.easeInOut"}, "animateFrame1")
		.from(bottomBar, {duration:0.3, x:300,  ease:"expo.easeInOut"}, "animateFrame1")


		//TEXT 1 AND 2 IN//
		.from([text1, text2], {duration:0.5, scale:0, ease: "back.out(1.2)", force3D:false, rotation:0.01}, "animateFrame1+=0.5")
		//TEXT 3 IN//

		// .addPause()

		// TEXT 1 2 and 3 OUT//
		.to([text1, text2, text3], {duration:0.5, scale:0, ease:"back.in(1.2)"}, "animateFrame1+=2")
		.to(topBar, {duration:0.3, x:300, ease:"expo.easeInOut"}, "animateFrame1+=2.5")
		.to([bottomBar, img1], {duration:0.3, x:-300, ease:"expo.easeInOut"}, "animateFrame1+=2.5")
		.from([logoSml, img2], {duration:0.3, x:300, ease:"expo.easeInOut"}, "animateFrame1+=2.5")



		.addLabel("animateFrame2", 4)
		//TEXT 4 5 and 6 IN//
		.from(text4, {duration:0.5, scale:0, ease: "back.out(1.2)", force3D:false, rotation:0.01}, "animateFrame2")
		//TEXT 5 IN//
		.set([text5, text6], {autoAlpha:1}, "animateFrame2+=0.5")
		.to([text5, text6], {duration:0.3, y:83, ease:"expo.easeInOut"}, "animateFrame2+=0.5")

		// .addPause()


		.addLabel("animateFrame3", 7)
		//FRAME WIPE//
		.from(blueWipe, {duration:0.5, y:-600, ease:"expo.easeInOut"}, "animateFrame3")
		.from(yellowWipe, {duration:0.5, y:600, ease:"expo.easeInOut"}, "animateFrame3")
		.from(text8, {duration:0.3, autoAlpha:0, ease:"expo.easeInOut"}, "animateFrame3+=0.2")
		.from(terms, {duration:0.3, autoAlpha:0, ease:"expo.easeInOut"}, "animateFrame3+=0.5")
		.from([text9, text10], {duration:0.5, scale:0, ease: "back.out(1.2)", force3D:false, rotation:0.01}, "animateFrame3+=0.6")

		.to([text8, text9, text10, terms], {duration:0.5, autoAlpha:0, ease:"expo.easeInOut"}, "animateFrame3+=2.5")

		.from([text11, legal], {duration:0.5, autoAlpha:0}, "animateFrame3+=3")
		.from(logo, {duration:0.5, autoAlpha:0}, "animateFrame3+=3.2")
		.from(cta, {duration:0.5, scale:0, ease: "back.out(1.2)", force3D:false, rotation:0.01}, "animateFrame3+=3.3")









        .pause();

		}
	
}

/*************************************************************************************************/
/* Event handlers ********************************************************************************/
/*************************************************************************************************/

function buttonHandler($e) {
	button 	= $e.currentTarget;
	type	= $e.type;

	switch (button) {
		case container:
			if 		(type === "mouseover") 	{  }
			else if (type === "mouseout") 	{  }
			else if (type === "click") 		{ 	window.open(clickTag); console.log('clickthrough to ' + clickTag);}
			break;
	}
}



/*************************************************************************************************/
/* Check page and Enabler has been loaded and initialised ****************************************/
/*************************************************************************************************/

function checkEnabler() {
	(Enabler.isInitialized()) ? enablerInitHandler() : Enabler.addEventListener(studio.events.StudioEvent.INIT, enablerInitHandler);
}

function enablerInitHandler() {
	(Enabler.isVisible()) ? init() : Enabler.addEventListener(studio.events.StudioEvent.VISIBLE, init);
}

domready(function() {
	console.log(":: dom ready ::");
	if (elementScrape()) checkEnabler();
});